<template>
    <div class="system-role-container">
        <el-card shadow="hover">
            <div class="system-user-search mb15">
                <div class="basic-line"></div>
                <div class="basic-line"></div>
                <el-button size="default" type="primary" class="ml10" v-throttle @click="handleSearch">
                    <el-icon>
                        <ele-Search />
                    </el-icon>
                    查询
                </el-button>
                <el-button size="default" type="success" class="ml10" @click="onOpenDialogRef('新增', '')">
                    <el-icon>
                        <ele-FolderAdd />
                    </el-icon>
                    新增巡检指标
                </el-button>
            </div>
            <el-table :data="inspectTargetData.data" style="width: 100%">
                <el-table-column type="index" label="序号" width="60" />
                <el-table-column prop="quota" label="指标名称" show-overflow-tooltip></el-table-column>
                <el-table-column prop="quotaUnit" label="指标单位" show-overflow-tooltip></el-table-column>
                <el-table-column prop="quotaType" label="指标类型" show-overflow-tooltip></el-table-column>
                <el-table-column prop="createUserName" label="创建人" show-overflow-tooltip></el-table-column>
                <el-table-column prop="gmtCreate" label="创建时间" show-overflow-tooltip></el-table-column>
                <el-table-column prop="lastEditUserName" label="最后修改人" show-overflow-tooltip></el-table-column>
                <el-table-column prop="gmtModitify" label="最后修改时间" show-overflow-tooltip></el-table-column>
                <el-table-column label="操作" width="150">
                    <template #default="scope">
                        <el-button size="small" text type="primary" @click="onOpenDialogRef('修改', scope.row)">修改</el-button>
                        <el-button size="small" text type="danger" @click="onDelProductionDevice(scope.row)">删除</el-button>
                    </template>
                </el-table-column>
            </el-table>
            <br />
            <el-pagination
                @size-change="onHandleSizeChange"
                @current-change="onHandleCurrentChange"
                :pager-count="5"
                :page-sizes="[10, 20, 30]"
                v-model:current-page="inspectTargetData.params.pageIndex"
                background
                v-model:page-size="inspectTargetData.params.pageSize"
                layout="total, sizes, prev, pager, next, jumper"
                :total="inspectTargetData.total"
                class="page-position"
            >
            </el-pagination>
            <br />
            <br />
        </el-card>
        <inspectTargetDialog ref="inspectTargetDialogRef" @refreshProductionDevice="initProductionDeviceTableData" />
    </div>
</template>

<script lang="ts">
import { toRefs, reactive, onMounted, ref, defineComponent } from 'vue';
import { ElMessageBox, ElMessage } from 'element-plus';
import inspectTargetDialog from './components/inspectTargetDialog.vue';
import { inspectTargetApi } from '/@/api/intellectInspectSystem/inspectTargetManage';

// 定义接口来定义对象的类型
interface TableData {
    quota: string;
    quotaUnit: string;
    quotaType: string;
    createUserName: string;
    gmtCreate: string;
    lastEditUserName: string;
    gmtModitify: string;
}
interface TableDataState {
    inspectTargetData: {
        data: Array<TableData>;
        total: number;
        loading: boolean;
        params: {
            pageIndex: number;
            pageSize: number;
        };
    };
}

export default defineComponent({
    name: 'productionDevice',
    components: { inspectTargetDialog },
    setup() {
        const inspectTargetDialogRef = ref();
        const state = reactive<TableDataState>({
            inspectTargetData: {
                data: [],
                total: 0,
                loading: false,
                params: {
                    pageIndex: 1,
                    pageSize: 10
                }
            }
        });
        // 初始化表格数据
        const initInspectTargetTableData = async () => {
            let res = await inspectTargetApi().getInspectTargetList(state.inspectTargetData.params);
            if (res.data.code === '200') {
                state.inspectTargetData.data = res.data.data.records;
                state.inspectTargetData.total = res.data.data.total;
            } else {
                ElMessage({
                    type: 'warning',
                    message: res.data.msg
                });
            }
        };

        // 打开生产装置弹窗
        const onOpenDialogRef = (type: string, value: any) => {
            inspectTargetDialogRef.value.openProductionDeviceDialog(type, value);
        };
        // 删除角色
        const onDelProductionDevice = (row: any) => {
            ElMessageBox.confirm(`此操作将永久删除该条生产装置：“${row.produceDeviceName}”，是否继续?`, '提示', {
                confirmButtonText: '确认',
                cancelButtonText: '取消',
                type: 'warning'
            })
                .then(async () => {
                    let res = await inspectTargetApi().deleteInspectTarget({ id: row.id });
                    if (res.data.code === '200') {
                        ElMessage({
                            type: 'success',
                            duration: 2000,
                            message: '删除成功'
                        });
                        await initInspectTargetTableData();
                    } else {
                        ElMessage({
                            type: 'warning',
                            message: res.data.msg
                        });
                    }
                })
                .catch(() => {});
        };

        const handleSearch = () => {
            initInspectTargetTableData();
        };
        // 分页改变
        const onHandleSizeChange = (val: number) => {
            state.inspectTargetData.params.pageSize = val;
            initInspectTargetTableData();
        };
        // 分页改变
        const onHandleCurrentChange = (val: number) => {
            state.inspectTargetData.params.pageIndex = val;
            initInspectTargetTableData();
        };
        // 页面加载时
        onMounted(() => {
            initInspectTargetTableData();
        });

        return {
            handleSearch,
            onOpenDialogRef,
            onHandleSizeChange,
            onDelProductionDevice,
            onHandleCurrentChange,
            inspectTargetDialog,
            inspectTargetDialogRef,
            initInspectTargetTableData,
            ...toRefs(state)
        };
    }
});
</script>

<style scoped></style>
